==> ejc-sddjsorg-api-3.0.0-20211013.093409-9-sources.jar: com/ejianc/business/production/vo/AcquisitionEquityVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-收购股权明细
 * 
 * @author generator
 * 
 */
public class AcquisitionEquityVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id
    private java.lang.String captailName; // 转让出资人名称
    private java.lang.String captailType; // 出资人类别
    private java.math.BigDecimal equityProportion; // 转让股权比例(%)
    private java.math.BigDecimal equityPrice; // 收购价格
    private java.lang.String equityPriceBig; // 收购价格(大写)
    private java.math.BigDecimal equityAssessment; // 收购股权的评估净产值
    private java.lang.String equityAssessmentBig; // 收购股权的评估净产值(大写)
    

    /**
     * 主表id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 转让出资人名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 转让出资人名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 转让股权比例(%)
     */
    public java.math.BigDecimal getEquityProportion() {
        return equityProportion;
    }

    /**
     * 转让股权比例(%)
     */
    public void setEquityProportion(java.math.BigDecimal equityProportion) {
        this.equityProportion = equityProportion;
    }
    /**
     * 收购价格
     */
    public java.math.BigDecimal getEquityPrice() {
        return equityPrice;
    }

    /**
     * 收购价格
     */
    public void setEquityPrice(java.math.BigDecimal equityPrice) {
        this.equityPrice = equityPrice;
    }
    /**
     * 收购价格(大写)
     */
    public java.lang.String getEquityPriceBig() {
        return equityPriceBig;
    }

    /**
     * 收购价格(大写)
     */
    public void setEquityPriceBig(java.lang.String equityPriceBig) {
        this.equityPriceBig = equityPriceBig;
    }
    /**
     * 收购股权的评估净产值
     */
    public java.math.BigDecimal getEquityAssessment() {
        return equityAssessment;
    }

    /**
     * 收购股权的评估净产值
     */
    public void setEquityAssessment(java.math.BigDecimal equityAssessment) {
        this.equityAssessment = equityAssessment;
    }
    /**
     * 收购股权的评估净产值(大写)
     */
    public java.lang.String getEquityAssessmentBig() {
        return equityAssessmentBig;
    }

    /**
     * 收购股权的评估净产值(大写)
     */
    public void setEquityAssessmentBig(java.lang.String equityAssessmentBig) {
        this.equityAssessmentBig = equityAssessmentBig;
    }
    
}

==> ejc-sddjsorg-api-3.0.0-20211028.092722-118-sources.jar: com/ejianc/business/production/vo/AcquisitionEquityVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-收购股权明细
 * 
 * @author generator
 * 
 */
public class AcquisitionEquityVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id
    private java.lang.String captailName; // 转让出资人名称
    private Long captailTypeId;
    private java.lang.String captailType; // 出资人类别

    private java.math.BigDecimal equityProportion; // 转让股权比例(%)
    private java.math.BigDecimal equityPrice; // 收购价格
    private java.lang.String equityPriceBig; // 收购价格(大写)
    private java.math.BigDecimal equityAssessment; // 收购股权的评估净产值
    private java.lang.String equityAssessmentBig; // 收购股权的评估净产值(大写)
    

    /**
     * 主表id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 转让出资人名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 转让出资人名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 转让股权比例(%)
     */
    public java.math.BigDecimal getEquityProportion() {
        return equityProportion;
    }

    /**
     * 转让股权比例(%)
     */
    public void setEquityProportion(java.math.BigDecimal equityProportion) {
        this.equityProportion = equityProportion;
    }
    /**
     * 收购价格
     */
    public java.math.BigDecimal getEquityPrice() {
        return equityPrice;
    }

    /**
     * 收购价格
     */
    public void setEquityPrice(java.math.BigDecimal equityPrice) {
        this.equityPrice = equityPrice;
    }
    /**
     * 收购价格(大写)
     */
    public java.lang.String getEquityPriceBig() {
        return equityPriceBig;
    }

    /**
     * 收购价格(大写)
     */
    public void setEquityPriceBig(java.lang.String equityPriceBig) {
        this.equityPriceBig = equityPriceBig;
    }
    /**
     * 收购股权的评估净产值
     */
    public java.math.BigDecimal getEquityAssessment() {
        return equityAssessment;
    }

    /**
     * 收购股权的评估净产值
     */
    public void setEquityAssessment(java.math.BigDecimal equityAssessment) {
        this.equityAssessment = equityAssessment;
    }
    /**
     * 收购股权的评估净产值(大写)
     */
    public java.lang.String getEquityAssessmentBig() {
        return equityAssessmentBig;
    }

    /**
     * 收购股权的评估净产值(大写)
     */
    public void setEquityAssessmentBig(java.lang.String equityAssessmentBig) {
        this.equityAssessmentBig = equityAssessmentBig;
    }

    public Long getCaptailTypeId() {
        return captailTypeId;
    }

    public void setCaptailTypeId(Long captailTypeId) {
        this.captailTypeId = captailTypeId;
    }
}
